@@ -1,12 +1,18 @@
 # -*- coding: utf-8 -*-
 
+"""
+ISBN extractint routine (and regexp)
+"""
+
 import re
 
 ############################################################
 # Extracting ISBN from book text
 ############################################################
 
-re_isbn = re.compile("(?:ISBN[ -]*(?:|10|13)|International Standard Book Number)[:\s]*(?:|, PDF ed.|, print ed.|\(pbk\)|\(electronic\))[:\s]*([-0-9Xx]{10,25})", re.MULTILINE)
+RE_ISBN = re.compile("(?:ISBN[ -]*(?:|10|13)|International Standard Book Number)[:\s]*(?:|, PDF ed.|, print ed.|\(pbk\)|\(electronic\))[:\s]*([-0-9Xx]{10,25})",
+                     re.MULTILINE)
+
 
 def look_for_isbn_in_text(text):
     """
@@ -14,18 +20,18 @@ def look_for_isbn_in_text(text):
     """
     isbns10 = []
     isbns13 = []
-    for m in re_isbn.finditer(text):
-        txt = m.group(1)
+    for match in RE_ISBN.finditer(text):
+        txt = match.group(1)
         txt = txt.replace("-", "")
-        l = len(txt)
-        if l == 10:
+        txt_len = len(txt)
+        if txt_len == 10:
             isbns10.append(txt)
-        elif l == 13:
+        elif txt_len == 13:
             isbns13.append(txt)
+    # TODO: more sophisticated choice if there are many isbn's
     if isbns13:
-        return isbns13[0]   # TODO: more sophisticated choice if there are many isbn's
+        return isbns13[0]
     elif isbns10:
         return isbns10[0]
     else:
         return None
-
