@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Autodetect ISBN for books kept inside 
+Autodetect ISBN for books kept inside
 Calibre <http://calibre-ebook.com/> database.
 
 Purpose
@@ -27,20 +27,20 @@ Prerequisities
 
 Calibre must be installed, properly configured and has
 some database (otherwise it does not make sense to run the script).
-The 
+The
     calibredb
 command must be in PATH (or CALIBREDB variable below can be modified
 to show full path of it).
 
 Tools providing commands
     pdftotext
-    catdoc 
+    catdoc
     djvutxt
     archmage
 must be installed and present in PATH. On Ubuntu Linux or Debian Linux
 those can be installed from standard repositories, just install the
 following packages
-    poppler-utils 
+    poppler-utils
     catdoc
     djvulibre-bin
     archmage
@@ -83,14 +83,12 @@ Sources are tracked on http://bitbucket.org/Mekk/calibre_utils
 from collections import namedtuple
 from mekk.calibre.calibre_util import  \
     find_calibre_books, save_isbn
-from mekk.calibre.disk_util import \
-    file_extension
 from mekk.calibre.text_extract import \
     grab_file_text_for_analysis, can_extract_text_from
 from mekk.calibre.isbn import look_for_isbn_in_text
 from mekk.calibre.config import standard_config
 
-config = standard_config()
+CONFIG = standard_config()
 
 ############################################################
 # Locating files for analysis
@@ -98,6 +96,7 @@ config = standard_config()
 
 IsbnItem = namedtuple('IsbnItem', 'id uuid title files')
 
+
 def locate_potential_isbn_files():
     """
     Locates all files which may be used for ISBN grabbing.
@@ -107,26 +106,27 @@ def locate_potential_isbn_files():
       extractors handle)
 
     Routine yields objects with fields:
-       id, 
-       uuid, 
+       id,
+       uuid,
        title
        files  (list of all possibly suitable files, at least one item)
     """
     checked_count = 0
-    for item_no, book in enumerate( find_calibre_books() ): # TODO: search
+    for item_no, book in enumerate(find_calibre_books()): # TODO: search
         if not book.isbn:
-            files = [ f
-                      for f in book.files
-                      if can_extract_text_from(f) ]
+            files = [f
+                     for f in book.files
+                     if can_extract_text_from(f)]
             if files:
                 checked_count += 1
-                yield IsbnItem(id = book.id,
-                               uuid = book.uuid,
-                               title = book.title,
-                               files = files)
-        if item_no > 0 and item_no % config.progress_report_every == 0:
+                yield IsbnItem(id=book.id,
+                               uuid=book.uuid,
+                               title=book.title,
+                               files=files)
+        if item_no > 0 and item_no % CONFIG.progress_report_every == 0:
             print "Info: %d files found, %d checked" % (item_no, checked_count)
 
+
 def find_files_with_new_isbn():
     """
     Checks files for ISBN. Yields all files for which it was found,
@@ -134,8 +134,8 @@ def find_files_with_new_isbn():
     """
     for item in locate_potential_isbn_files():
         candid = set()
-        for fl in item.files:
-            txt = grab_file_text_for_analysis(fl)
+        for file_name in item.files:
+            txt = grab_file_text_for_analysis(file_name)
             isbn = look_for_isbn_in_text(txt)
             if isbn:
                 candid.add(isbn)
@@ -143,12 +143,17 @@ def find_files_with_new_isbn():
             isbn = candid.pop()
             yield item, isbn
         elif len(candid) > 1:
-            raise Exception("ISBN conflict in %s: %s" % (str(item), str(candid)))
+            raise Exception(
+                "ISBN conflict in %s: %s" % (str(item), str(candid)))
 
 ############################################################
 # Main
 ############################################################
 
+
 def run():
+    """
+    Run calibre_guess_and_add_isbn script
+    """
     for item, isbn in find_files_with_new_isbn():
         save_isbn(item, isbn)
